@@ -27,7 +27,8 @@ Chj::CPAN::ModulePODUrl - get module POD url on metacpan
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
