@@ -33,7 +33,8 @@ early, nor does it localize error variables in its DESTROY method.
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
