@@ -117,7 +117,8 @@ find the elements in the parts that have been pre-serialized.
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
